==> open-cluster-management-apps-model-6.6.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/HourRangeFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HourRangeFluentImpl<A extends HourRangeFluent<A>> extends BaseFluent<A> implements HourRangeFluent<A>{
  public HourRangeFluentImpl() {
  }
  public HourRangeFluentImpl(HourRange instance) {
    this.withEnd(instance.getEnd()); 
    this.withStart(instance.getStart()); 
  }
  private String end;
  private String start;
  public String getEnd() {
    return this.end;
  }
  public A withEnd(String end) {
    this.end=end; return (A) this;
  }
  public Boolean hasEnd() {
    return this.end != null;
  }
  public String getStart() {
    return this.start;
  }
  public A withStart(String start) {
    this.start=start; return (A) this;
  }
  public Boolean hasStart() {
    return this.start != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HourRangeFluentImpl that = (HourRangeFluentImpl) o;
    if (end != null ? !end.equals(that.end) :that.end != null) return false;
    if (start != null ? !start.equals(that.start) :that.start != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(end,  start,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (end != null) { sb.append("end:"); sb.append(end + ","); }
    if (start != null) { sb.append("start:"); sb.append(start); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-apps-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/HourRangeFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HourRangeFluentImpl<A extends HourRangeFluent<A>> extends BaseFluent<A> implements HourRangeFluent<A>{
  public HourRangeFluentImpl() {
  }
  public HourRangeFluentImpl(HourRange instance) {
    if (instance != null) {
      this.withEnd(instance.getEnd());
      this.withStart(instance.getStart());
    }
  }
  private String end;
  private String start;
  public String getEnd() {
    return this.end;
  }
  public A withEnd(String end) {
    this.end=end; return (A) this;
  }
  public Boolean hasEnd() {
    return this.end != null;
  }
  public String getStart() {
    return this.start;
  }
  public A withStart(String start) {
    this.start=start; return (A) this;
  }
  public Boolean hasStart() {
    return this.start != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HourRangeFluentImpl that = (HourRangeFluentImpl) o;
    if (!java.util.Objects.equals(end, that.end)) return false;

    if (!java.util.Objects.equals(start, that.start)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(end,  start,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (end != null) { sb.append("end:"); sb.append(end + ","); }
    if (start != null) { sb.append("start:"); sb.append(start); }
    sb.append("}");
    return sb.toString();
  }
  
}
